@@ -33,7 +33,7 @@ class AdaptiveHitMissPOD(POD):
         defect sizes.
     outputDOE : 2-d sequence of float
         Vector of the signals, of dimension 1.
-    physicalModel : :py:class:`~openturns.NumericalMathFunction`
+    physicalModel : :py:class:`openturns.NumericalMathFunction`
         True model used to compute the real hit miss value of the signal value 
         to be added to the DOE.
     nMorePoints : positive int
@@ -755,4 +755,4 @@ class AdaptiveHitMissPOD(POD):
         classifierSample = algoClassifier(np.array(fullSamplePred))[:, 1]
         classifierSample = np.reshape(classifierSample, (self._samplingSize,
                                        self._defectNumber), 'F')
-        return ot.NumericalSample(classifierSample)
\ No newline at end of file
+        return ot.NumericalSample(classifierSample)
