@@ -30,7 +30,7 @@ class AdaptiveSignalPOD(POD, KrigingBase):
         defect sizes.
     outputDOE : 2-d sequence of float
         Vector of the signals, of dimension 1.
-    physicalModel : :py:class:`~openturns.NumericalMathFunction`
+    physicalModel : :py:class:`openturns.NumericalMathFunction`
         True model used to compute the real signal value to be added to the DOE.
     nMorePoints : positive int
         The number of points to add to the DOE, computed by the *physicalModel*.
@@ -191,7 +191,7 @@ class AdaptiveSignalPOD(POD, KrigingBase):
             print('Building the kriging model')
             print('Optimization of the covariance model parameters...')
 
-        if LooseVersion(ot.__version__) == '1.9':
+        if LooseVersion(ot.__version__) >= '1.9':
             llDim = algoKriging.getReducedLogLikelihoodFunction().getInputDimension()
         else:
             llDim = algoKriging.getLogLikelihoodFunction().getInputDimension()
@@ -249,7 +249,7 @@ class AdaptiveSignalPOD(POD, KrigingBase):
                 signalsAugmented.add(metamodel(candidate))
                 # create a temporary kriging model with the new doe and without
                 # updating the covariance model parameters
-                if LooseVersion(ot.__version__) == '1.9':
+                if LooseVersion(ot.__version__) >= '1.9':
                     algoKrigingTemp = ot.KrigingAlgorithm(inputAugmented, signalsAugmented,
                                                           self._covarianceModel,
                                                           self._basis,
@@ -260,9 +260,15 @@ class AdaptiveSignalPOD(POD, KrigingBase):
                                                           self._covarianceModel,
                                                           True)
                 if LooseVersion(ot.__version__) > '1.6':
-                    optimizer = algoKrigingTemp.getOptimizationSolver()
+                    try:
+                        optimizer = algoKrigingTemp.getOptimizationAlgorithm()
+                    except:
+                        optimizer = algoKrigingTemp.getOptimizationSolver()
                     optimizer.setMaximumIterationNumber(0)
-                    algoKrigingTemp.setOptimizationSolver(optimizer)
+                    try:
+                        algoKrigingTemp.setOptimizationAlgorithm(optimizer)
+                    except:
+                        algoKrigingTemp.setOptimizationSolver(optimizer)
 
                 algoKrigingTemp.run()
                 krigingResultTemp = algoKrigingTemp.getResult()
@@ -315,7 +321,7 @@ class AdaptiveSignalPOD(POD, KrigingBase):
                 optimizer = algoKriging.getOptimizationSolver()
                 optimizer.setMaximumIterationNumber(0)
                 algoKriging.setOptimizationSolver(optimizer)
-            elif LooseVersion(ot.__version__) == '1.8':
+            elif LooseVersion(ot.__version__) >= '1.8':
                 algoKriging.setOptimizeParameters(False)
 
             algoKriging.run()
@@ -327,7 +333,7 @@ class AdaptiveSignalPOD(POD, KrigingBase):
                 if self._verbose:
                     print('Optimization of the covariance model parameters...')
 
-                if LooseVersion(ot.__version__) == '1.9':
+                if LooseVersion(ot.__version__) >= '1.9':
                     llDim = algoKriging.getReducedLogLikelihoodFunction().getInputDimension()
                 else:
                     llDim = algoKriging.getLogLikelihoodFunction().getInputDimension()
@@ -474,4 +480,4 @@ class AdaptiveSignalPOD(POD, KrigingBase):
         samplePred = ot.NumericalSample(size, dim)
         samplePred[:, 0] = ot.NumericalSample(size, [defect])
         samplePred[:, 1:] = X
-        return samplePred
\ No newline at end of file
+        return samplePred
