@@ -598,7 +598,7 @@ class PolynomialChaosPOD(POD):
 
         Returns
         -------
-        dist : :class:`openturns.Distribution`
+        dist : :py:class:`openturns.Distribution`
             The distribution of the coefficients. 
         """
         return self._coefsDist
@@ -637,7 +637,10 @@ class PolynomialChaosPOD(POD):
 
         if self._projectionStrategy is None:
             # sparse polynomial chaos
-            basis_sequence_factory = ot.LAR()
+            try:
+                basis_sequence_factory = ot.LARS()
+            except:
+                basis_sequence_factory = ot.LAR()
             fitting_algorithm = ot.KFold()
             approximation_algorithm = ot.LeastSquaresMetaModelSelectionFactory(
                                       basis_sequence_factory, fitting_algorithm)
@@ -696,4 +699,4 @@ class PolynomialChaosPOD(POD):
         # compute the POD for all defect sizes
         POD = np.mean(chaosRandomSample > self._detectionBoxCox, axis=0)
 
-        return POD
\ No newline at end of file
+        return POD
